cole Library Reference Manual
Prev | Chapter 5. Legal issues | Next

# Trademarks

"Microsoft Word", "Microsoft Excel", "Microsoft Publisher" and "Microsoft Power Point" are trademarks of Microsoft Corporation.

"StarOffice" may be is a trademark of StarDivision.

"FlashPix" may be is a trademark.

"UNIX" is a trademark.

"Free Software" is not trademark of anyone, but it's an important term in the Free Software community, and for the Free Software Foundation.

All other trademarks are the property of their respective owners.

If another trademark is mentioned in this document and it needs to be listed above, please email to the maintainer (<arturo@directmail.org>).

Prev | Home | Next
Legal issues | Up | Copyright and disclaimer